/*************************************************************************************
*  Copyright (c) 1997-1998 by Joseph Parrello. All Rights Reserved.                  *
*  Site   : http://space.tin.it/computer/giparrel                                    *
*  E-Mail : joparrel@tin.it, giusparr@tin.it, giparre@tin.it                         *
*                                                                                    *
*  Revision:   1.1a  (April 3, 1998).                                                *
*                                                                                    *
*  Definition of JPFlatTextGadget class.                                             *
*                                                                                    *
*  Read JPFLTTXT.TXT for use and license.                                            *
*                                                                                    *
*  Only for OWL 5.02 and 5.01 users.                                                 *
*  OWL and ObjectWindows are trademarks of Borland International.                    *
*                                                                                    *
*  THIS CLASS AND INFORMATION IS PROVIDED "AS IS" WITHOUT WARRANTY OF                *
*  ANY KIND, EITHER EXPRESSED OR IMPLIED, INCLUDING BUT NOT LIMITED TO               *
*  THE IMPLIED WARRANTIES OF MERCHANTABILITY AND/OR FITNESS FOR A                    *
*  PARTICULAR PURPOSE.                                                               *
*************************************************************************************/
#include <owl/pch.h>

#if !defined(OWL_UIHELPER_H)
#include <owl/uihelper.h>
#endif
#include "jpflttxt.h"


//{{JPFlatTextGadget Implementation}}


JPFlatTextGadget::JPFlatTextGadget(int id, TBorderStyle borderstyle, TAlign align, uint numChars, const char far* text, TFont* font, bool Flat)
:
    TTextGadget(id, borderstyle, align, numChars, text, font)
{
    defStyle = borderstyle;
    AutoTracking = Flat;
    if ((AutoTracking) && (defStyle==ButtonUp))
       SetFlatState(fsNormal);
}


JPFlatTextGadget::~JPFlatTextGadget()
{
  // INSERT>> Your destructor code here.

}


void JPFlatTextGadget::MouseEnter(uint modKeys, TPoint& point)
{
  TTextGadget::MouseEnter(modKeys, point);

  if (Window->GetHintMode() == TGadgetWindow::EnterHints)
        Window->SetHintCommand(GetId());
  if ((AutoTracking) && (GetEnabled()) && (defStyle==ButtonUp))
  		SetFlatState(fsUp);
}


void JPFlatTextGadget::MouseLeave(uint modKeys, TPoint& point)
{
  TTextGadget::MouseLeave(modKeys, point);

  if (Window->GetHintMode() == TGadgetWindow::EnterHints)
        Window->SetHintCommand(-1);
  if ((AutoTracking) && (defStyle==ButtonUp))
        SetFlatState(fsNormal);
}

void
JPFlatTextGadget::SetFlatState(FlatState state, bool update)
{
switch (state)
	{
   case fsNormal:
      CurrentFlatState = fsNormal;
      break;

   case fsUp:
      if (GetEnabled())
      CurrentFlatState = fsUp;
      else return;
      break;

   case fsDown:
      if (GetEnabled())
      CurrentFlatState = fsDown;
      else return;
      break;
   }
if (update)
	{
   InvalidateRect(TRect(0, 0, Bounds.Width(), Bounds.Height()), true);
	Update();
   }
}

JPFlatTextGadget::FlatState
JPFlatTextGadget::GetFlatState() const
{
  return CurrentFlatState;
}

void JPFlatTextGadget::PaintBorder(TDC& dc)
{
   if ((AutoTracking) && (defStyle==ButtonUp))
   	{
      if (GetFlatState()==fsUp)
         {
         TRect rect(0,0,Bounds.Width(),Bounds.Height());
         #if defined(BI_PLAT_WIN16)
         TUIBorder border(rect, TUIBorder::TEdge(TUIBorder::WndRaised), TUIBorder::Rect | TUIBorder::Adjust);
         #elif defined(BI_PLAT_WIN32)
         TUIBorder border(rect, TUIBorder::TEdge(TUIBorder::RaisedInner), TUIBorder::Rect | TUIBorder::Adjust);
         #endif
         border.Paint(dc);
         }
      else if (GetFlatState()==fsDown)
         {
         BorderStyle = Recessed;
         TTextGadget::PaintBorder(dc);
         }
      }
   else  TTextGadget::PaintBorder(dc);
}

void JPFlatTextGadget::SetTracking(bool enable)
{
  if (enable)
  	{
   AutoTracking = true;
   SetFlatState(fsNormal);
   }
  else
  	{
   AutoTracking = false;
   SetBorderStyle(defStyle);
   Invalidate();
   Update();
   }
}

